library(car)
library("googleVis")

# read the data
data<-read.csv("indicators for regression.csv", header=TRUE)
head(data)
colnames(data)<-c("country","countrycode","GDP","remitt_ofGDP","remitt","population","phones")

migration <- read.csv("migration.csv", header=FALSE)
colnames(migration)<-c("country", "immigrants","emigrants")

world_bank_class<-read.csv("world_bank_country_class.csv", header=FALSE)
colnames(world_bank_class)<-c("country", "income_classification")

# merge by country name
data_merged_all<-merge(data,migration,by="country", all.x=TRUE)
data_merged_all<-merge(data_merged_all,world_bank_class,by="country", all.x=TRUE)

# model 1
fit1 <- lm(phones ~ GDP, data=data_merged_all,na.action=na.omit)
summary(fit1)

# model 2
fit <- lm(phones ~ GDP + immigrants, data=data_merged_all,na.action=na.omit)
summary(fit)

# test for multicolinearity, > 2 means there might be a problem
sqrt(vif(fit))

# plot diagnostics
plot(fit)

# descriptive statistics
mean(data_merged_all$GDP, na.rm=T)
sd(data_merged_all$GDP, na.rm=T)
sum(!is.na(data_merged_all$GDP))

mean(data_merged_all$phones, na.rm=T)
sd(data_merged_all$phones, na.rm=T)
sum(!is.na(data_merged_all$phones))

mean(data_merged_all$immigrants, na.rm=T)
sd(data_merged_all$immigrants, na.rm=T)
sum(!is.na(data_merged_all$immigrants))

# bubble chart
chart_data<-data_merged_all
chart_data$log_GDP<-log10(data_merged_all$GDP)
bubble <- gvisBubbleChart(chart_data, idvar="country", xvar="phones", yvar="GDP",
                          colorvar="income_classification", sizevar="immigrants",
                          options=list(sizeAxis= "{minSize:5, maxSize:100}",
                                       width=3000, height=2000, fontSize=32,
                                       hAxis="{title: 'Mobile phones per 100 population'}",
                                       vAxis= "{logScale:true, title: 'Gross Domestic Product (GDP) per capita, USD'}",
                                       bubble="{textStyle: {fontSize: 14}}"))

plot(bubble)

cat(createGoogleGadget(bubble), file="bubblechart.xml")
